# ApplicationAdditionalContext

Configuration of additional information passed to the application by the Agilicus System 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**include_user_context_headers** | **bool** | if set to &#x60;true&#x60; additional context headers will be forward to the application along with the request. An example of a context header is the user&#39;s ID in the Agilicus System  | defaults to False
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


